UpdateWidget class

Inheritance

Constructors

UpdateWidget({Key? key, double width = 0.0, required String title, required String updateContent, required VoidCallback onUpdate, double titleTextSize = 16.0, double contentTextSize = 14.0, double buttonTextSize = 14.0, double progress = -1.0, Color progressBackgroundColor = const Color(0xFFFFCDD2), Widget? topImage, double extraHeight = 5.0, double radius = 4.0, Color themeColor = Colors.red, bool enableIgnore = false, VoidCallback? onIgnore, bool isForce = false, String updateButtonText = '更新', String ignoreButtonText = '忽略此版本', VoidCallback? onClose})

Properties

buttonTextSize → double
按钮文字的大小
final
contentTextSize → double
更新文字内容的大小
final
enableIgnore → bool
可忽略更新
final
extraHeight → double
拓展高度(适配顶部图片高度不一致的情况)
final
hashCode → int
The hash code for this object.
no setterinherited
ignoreButtonText → String
忽略按钮内容
final
isForce → bool
是否是强制更新
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onClose → VoidCallback?
更新事件
final
onIgnore → VoidCallback?
更新事件
final
onUpdate → VoidCallback
更新事件
final
progress ↔ double
getter/setter pair
progressBackgroundColor → Color
进度条的背景颜色
final
radius → double
边框圆角大小
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
themeColor → Color
主题颜色
final
title → String
升级标题
final
titleTextSize → double
标题文字的大小
final
topImage → Widget?
顶部图片
final
updateButtonText → String
更新按钮内容
final
updateContent → String
更新内容
final
width → double
对话框的宽度
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _UpdateWidgetState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
update(double progress) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited